@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
+
+from __future__ import annotations
+
 import sys
 import weakref
+from typing import TYPE_CHECKING
 
 import numpy as np
 from qtpy import QtCore as QC
@@ -12,6 +16,9 @@ from plotpy.items.curve.errorbar import ErrorBarCurveItem
 from plotpy.items.image.misc import get_image_from_qrect
 from plotpy.mathutils.geometry import rotate, translate, vector_angle, vector_norm
 
+if TYPE_CHECKING:
+    from plotpy.items import AnnotatedObliqueRectangle, AnnotatedSegment
+
 try:
     from plotpy._scaler import INTERP_LINEAR, _scale_tr
 except ImportError:
@@ -218,7 +225,7 @@ def compute_oblique_section(item, obj, debug=False):
 
     ixr = 0.5 * (ixb + ixa)
     iyr = 0.5 * (iyb + iya)
-    mat = translate(ixr, iyr) * rotate(-angle) * translate(-0.5 * destw, -0.5 * desth)
+    mat = translate(ixr, iyr) @ rotate(-angle) @ translate(-0.5 * destw, -0.5 * desth)
     _scale_tr(data, mat, dst_image, dst_rect, (1.0, 0.0, np.nan), (INTERP_LINEAR,))
 
     if debug:
@@ -243,7 +250,10 @@ def compute_oblique_section(item, obj, debug=False):
             TEMP_ITEM.param.update_item(TEMP_ITEM)
         plot.replot()
 
-    ydata = np.ma.fix_invalid(dst_image, copy=debug).mean(axis=1)
+    fixed_image = np.ma.fix_invalid(dst_image, copy=debug)
+    if fixed_image.size == 0:
+        return np.array([]), np.array([])
+    ydata = fixed_image.mean(axis=1)
     xdata = item.get_x_values(0, ydata.size)[: ydata.size]
     try:
         xdata -= xdata[0]
@@ -311,6 +321,9 @@ class CrossSectionItem(ErrorBarCurveItem):
         sectx, secty = self.get_cross_section(obj)
         if secty.size == 0 or np.all(np.isnan(secty)):
             sectx, secty = np.array([]), np.array([])
+        elif self.param.curvestyle != "Steps" and sectx.size > 1:
+            # Center the symbols at the middle of pixels:
+            sectx[:-1] += np.mean(np.diff(sectx) / 2)
         if self.orientation() == QC.Qt.Orientation.Vertical:
             self.process_curve_data(secty, sectx)
         else:
@@ -423,14 +436,8 @@ class ObliqueCrossSectionItem(CrossSectionItem):
 
     DEBUG = False
 
-    def __init__(self, curveparam=None, errorbarparam=None):
-        CrossSectionItem.__init__(self, curveparam, errorbarparam)
-
-    def update_curve_data(self, obj):
-        """
-
-        :param obj:
-        """
+    def update_curve_data(self, obj: AnnotatedObliqueRectangle) -> None:
+        """Update curve data"""
         source = self.get_source_image()
         rect = obj.get_bounding_rect_coords()
         if rect is not None and source.data is not None:
@@ -444,3 +451,53 @@ class ObliqueCrossSectionItem(CrossSectionItem):
     def update_scale(self):
         """ """
         pass
+
+
+def compute_line_section(
+    data: np.ndarray, row0, col0, row1, col1
+) -> tuple[np.ndarray, np.ndarray]:
+    """Return intensity profile of data along a line
+
+    Args:
+        data: 2D array
+        row0, col0: start point
+        row1, col1: end point
+    """
+    # Keep coordinates inside the image
+    row0 = max(0, min(row0, data.shape[0] - 1))
+    col0 = max(0, min(col0, data.shape[1] - 1))
+    row1 = max(0, min(row1, data.shape[0] - 1))
+    col1 = max(0, min(col1, data.shape[1] - 1))
+    # Keep coordinates in the right order
+    row0, row1 = min(row0, row1), max(row0, row1)
+    col0, col1 = min(col0, col1), max(col0, col1)
+    # Extract the line
+    line = np.zeros((2, max(abs(row1 - row0), abs(col1 - col0)) + 1), dtype=np.float64)
+    line[0, :] = np.linspace(row0, row1, line.shape[1])
+    line[1, :] = np.linspace(col0, col1, line.shape[1])
+    # Interpolate the line
+    y = np.array([data[int(r), int(c)] for r, c in line.T])
+    x = np.arange(y.size)
+    return x, y
+
+
+# Line cross section item
+class LineCrossSectionItem(CrossSectionItem):
+    """A Qwt item representing line cross section data"""
+
+    def update_curve_data(self, obj: AnnotatedSegment) -> None:
+        """Update curve data"""
+        source = self.get_source_image()
+        rect = obj.get_rect()
+        if rect is not None and source.data is not None:
+            x0, y0, x1, y1 = obj.get_rect()
+            c0, r0 = source.get_closest_pixel_indexes(x0, y0)
+            c1, r1 = source.get_closest_pixel_indexes(x1, y1)
+            sectx, secty = compute_line_section(source.data, r0, c0, r1, c1)
+            if secty.size == 0 or np.all(np.isnan(secty)):
+                sectx, secty = np.array([]), np.array([])
+            self.process_curve_data(sectx, secty, None, None)
+
+    def update_scale(self):
+        """ """
+        pass
